.. Molo documentation master file, created by
   sphinx-quickstart on Fri May 29 11:39:46 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.


Welcome to Molo's documentation!
================================

.. include:: badges.rst

Molo is a set of tools for publishing mobi sites with a community focus. It is built on top of `Django`_ and `Wagtail`_.


Contents
--------

.. toctree::
   :maxdepth: 2

   installation
   getting-started
   molo_bundle
   features
   multiple-languages
   merged-cms
   template-tags
   template-patterns
   testing
   api
   plugins
   release-notes

.. _`Django`: https://www.djangoproject.com/
.. _`Wagtail`: http://wagtail.io
